========================
Dataset Tools
========================

This is a collection of tools for working with the datasets referenced from this repository.

Different packages are available for

* Downloading the datasets and extracting them
* Processing specific datasets, e.g. generating images from the raw HOMUS dataset.

The package ``omrdatasettools.downloaders`` contains one class per dataset, that is capable of downloading
and extracting the respective dataset. To see how they work, each of them has a main-function that can
be executed as it is.

`Back to main page <README.md>`_